@@ -1,7 +1,7 @@
 """
 Type annotations for amplifybackend service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/literals.html)
 
 Usage::
 
@@ -22,6 +22,7 @@ else:
 __all__ = (
     "AdditionalConstraintsElementType",
     "AuthResourcesType",
+    "AuthenticatedElementType",
     "DeliveryMethodType",
     "ListBackendJobsPaginatorName",
     "MFAModeType",
@@ -31,14 +32,13 @@ __all__ = (
     "OAuthScopesElementType",
     "RequiredSignUpAttributesElementType",
     "ResolutionStrategyType",
+    "ServiceNameType",
     "ServiceType",
     "SignInMethodType",
     "StatusType",
-    "AmplifyBackendServiceName",
+    "UnAuthenticatedElementType",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
-    "RegionName",
 )
 
 
@@ -46,6 +46,7 @@ AdditionalConstraintsElementType = Literal[
     "REQUIRE_DIGIT", "REQUIRE_LOWERCASE", "REQUIRE_SYMBOL", "REQUIRE_UPPERCASE"
 ]
 AuthResourcesType = Literal["IDENTITY_POOL_AND_USER_POOL", "USER_POOL_ONLY"]
+AuthenticatedElementType = Literal["CREATE_AND_UPDATE", "DELETE", "READ"]
 DeliveryMethodType = Literal["EMAIL", "SMS"]
 ListBackendJobsPaginatorName = Literal["list_backend_jobs"]
 MFAModeType = Literal["OFF", "ON", "OPTIONAL"]
@@ -75,10 +76,11 @@ RequiredSignUpAttributesElementType = Literal[
     "ZONE_INFO",
 ]
 ResolutionStrategyType = Literal["AUTOMERGE", "LAMBDA", "NONE", "OPTIMISTIC_CONCURRENCY"]
+ServiceNameType = Literal["S3"]
 ServiceType = Literal["COGNITO"]
 SignInMethodType = Literal["EMAIL", "EMAIL_AND_PHONE_NUMBER", "PHONE_NUMBER", "USERNAME"]
 StatusType = Literal["LATEST", "STALE"]
-AmplifyBackendServiceName = Literal["amplifybackend"]
+UnAuthenticatedElementType = Literal["CREATE_AND_UPDATE", "DELETE", "READ"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -88,10 +90,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -106,6 +110,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -160,6 +165,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -181,6 +187,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -207,6 +214,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -220,6 +228,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -265,7 +274,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -294,11 +305,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -308,6 +321,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -365,32 +379,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal["list_backend_jobs"]
-RegionName = Literal[
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-west-1",
-    "eu-west-2",
-    "us-east-1",
-    "us-east-2",
-    "us-west-2",
-]
