@@ -1,20 +1,19 @@
 """
 Type annotations for amplifybackend service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html)
 
 Usage::
 
     ```python
-    from boto3.session import Session
+    import boto3
 
-    from mypy_boto3_amplifybackend.client import AmplifyBackendClient
+    from mypy_boto3_amplifybackend import AmplifyBackendClient
     from mypy_boto3_amplifybackend.paginator import (
         ListBackendJobsPaginator,
     )
 
-    session = Session()
-    client: AmplifyBackendClient = session.client("amplifybackend")
+    client: AmplifyBackendClient = boto3.client("amplifybackend")
 
     list_backend_jobs_paginator: ListBackendJobsPaginator = client.get_paginator("list_backend_jobs")
     ```
@@ -41,8 +40,8 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListBackendJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators/#listbackendjobspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
     """
 
     def paginate(
@@ -53,9 +52,9 @@ class ListBackendJobsPaginator(Boto3Paginator):
         JobId: str = ...,
         Operation: str = ...,
         Status: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBackendJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators/#listbackendjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
